console games
=============

.. image:: https://raw.githubusercontent.com/maxzheng/console-games/master/docs/console-games.jpg
 :alt: Console Games

Four games are available:

1. **Geometry Bash**: Bash the squares before they get you and watch out for the money boss! Don't like geometry? You will love this one!! :D
2. **Number Crush**: Great game to train your kids' basic math skill. Answer quickly or get crushed. My son needs to crush 5 to earn 1 minute of screen time and loves doing it daily. :)
3. **Wasp Invasion**: Wasp kaijus have invaded Earth! Luckily, you got your flamethrower with you to save the day. FLAMES ON!!
4. **THE LAST SURVIVOR!!**: Kill the zombies to survive the apocalypse where you are the last survivor. Level up to get machine gun, grenades, and flamethrower!! Game design by my kids.

To play using Docker::

    docker run -it --rm maxzheng/console-games

To install using autopip_::

    sudo pip3 install autopip
    app install console-games

If you have trouble using `autopip`, you can install using `pip3` directly too::

    pip3 install console-games

And then start playing::

    play

Enjoy! And come back soon for more games!!

Links & Contact Info
====================

| Docker Image: https://hub.docker.com/r/maxzheng/console-games
| Python Package: https://pypi.python.org/pypi/console-games
| Source Code: https://github.com/maxzheng/console-games
| Report Issues: https://github.com/maxzheng/console-games/issues
|
| Connect: https://www.linkedin.com/in/maxzheng
| Contact: maxzheng.os @t gmail.com

.. _autopip: https://pypi.python.org/pypi/autopip
